==> manaplus_1.3.9.1.orig.tar.xz: manaplus-1.3.9.1/src/gui/widgets/horizontcontainer.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011-2013  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef GUI_WIDGETS_HORIZONTCONTAINER_H
#define GUI_WIDGETS_HORIZONTCONTAINER_H

#include "gui/widgets/container.h"

#include <guichan/widgetlistener.hpp>

#include "localconsts.h"

/**
 * A widget container.
 *
 * This container places it's contents veritcally.
 */
class HorizontContainer final : public Container, public gcn::WidgetListener
{
    public:
        HorizontContainer(const Widget2 *const widget,
                          const int height, const int spacing);

        A_DELETE_COPY(HorizontContainer)

        void add(gcn::Widget *widget) override;

        void add(gcn::Widget *widget, int spacing);

        void clear() override;

        void widgetResized(const gcn::Event &event) override;

    protected:
        int mSpacing;
        int mCount;
        int mLastX;
};

#endif  // GUI_WIDGETS_HORIZONTCONTAINER_H

==> manaplus_1.4.2.15.orig.tar.xz: manaplus-1.4.2.15/src/gui/widgets/horizontcontainer.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011-2014  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef GUI_WIDGETS_HORIZONTCONTAINER_H
#define GUI_WIDGETS_HORIZONTCONTAINER_H

#include "gui/widgets/container.h"

#include <guichan/widgetlistener.hpp>

#include "localconsts.h"

/**
 * A widget container.
 *
 * This container places it's contents veritcally.
 */
class HorizontContainer final : public Container, public gcn::WidgetListener
{
    public:
        HorizontContainer(const Widget2 *const widget,
                          const int height, const int spacing);

        A_DELETE_COPY(HorizontContainer)

        void add(gcn::Widget *widget) override final;

        void add(gcn::Widget *const widget, const int spacing);

        void clear() override;

        void widgetResized(const gcn::Event &event) override final;

    protected:
        int mSpacing;
        int mCount;
        int mLastX;
};

#endif  // GUI_WIDGETS_HORIZONTCONTAINER_H
